/**
 * @package n3t Contact plugin
 * @author Pavel Poles - n3t.cz
 * @copyright (C) 2014 - 2018 - Pavel Poles - n3t.cz
 * @license GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
**/

n3tContact = window.n3tContact || {};

n3tContact.renderMessages = function(messages, form) {
    var $ = jQuery.noConflict(), $container, $div, $h4, $divList, $p;
    n3tContact.removeMessages(form);
    if (typeof(form) !== 'undefined') {
        $container = $(form).find('.message-container');
        if (!$container.length)
          $container = $('#system-message-container');
    } else
      $container = $('#system-message-container');    

    $.each(messages, function(type, item) {
        $div = $('<div/>', {
            'id' : 'system-message',
            'class' : 'alert alert-' + type
        });
        $container.append($div)

        $h4 = $('<h4/>', {
            'class' : 'alert-heading',
            'text' : Joomla.JText._(type)
        });
        $div.append($h4);

        $divList = $('<div/>');
        $.each(item, function(index, item) {
            $p = $('<p/>', {
                html : item
            });
            $divList.append($p);
        });
        $div.append($divList);
    });
    var $scrollParent = $container.scrollParent();
    var scrollParent = $scrollParent.get(0);
    if (scrollParent == document) {
      $scrollParent = $('html, body');
      scrollParent = $scrollParent.get(0);
    }
    var top = $scrollParent.scrollTop();
    var element = $container;
    while (element.get(0) !== scrollParent && element.get(0) !== $('html').get(0)) {
      top += element.position().top;
      element = element.offsetParent();
    }
	  $scrollParent.stop().animate({
      'scrollTop': top
    }, 500, 'swing');
};

n3tContact.renderMessage = function(type, message, form) {
  var messages = {};
  messages[type] = [message];  
  n3tContact.renderMessages(messages, form);
};

n3tContact.removeMessages = function(form) {
    var $ = jQuery.noConflict(), $container;
    if (typeof(form) !== 'undefined') {
        $container = $(form).find('.message-container');
        if (!$container.length)
          $container = $('#system-message-container');
    } else
      $container = $('#system-message-container');    

    jQuery($container).empty();
}

n3tContact.ajaxForm = function(form) {
  var $ = jQuery.noConflict(),
    systemMessageContainer = $('#system-message-container'),
    container = form.find('.message-container'),
    buttons = form.find('input[type=submit],input[type=image],button[type=submit],button[type=image]');
  if (!container.length) {
    container = $('<div class="message-container" />');
    form.prepend(container);
  }

  var clicks = buttons.data('events').click.slice();
  buttons.unbind('click').click(function() {
    systemMessageContainer.attr('id', '');
    container.attr('id', 'system-message-container');
  });
  $.each(clicks, function(i, v) {
    buttons.click(v);
  });
  buttons.click(function() {
    container.attr('id', '');
    systemMessageContainer.attr('id', 'system-message-container');
  });

  form.submit(function (e) {
    form.addClass('n3tContactLoading');    
    var url = form.attr('action');
    url += (url.indexOf('?') == -1) ? '?' : '&';
    url += 'format=json';
    var data = form.serialize();      
    jQuery.ajax({        
      type: form.attr('method'),
      url: url,
      dataType: "json",
      async: true,
      data: data
    }).done(function(data){
      if (data.messages)
        n3tContact.renderMessages(data.messages, form);
      else  if (data.message) 
        n3tContact.renderMessage(data.success ? 'success' : 'warning', data.message, form);         
      else if (!data.success) 
        n3tContact.renderMessage('error', Joomla.JText._('PLG_SYSTEM_N3TCONTACT_JS_UNKNOWN_ERROR'), form);
      else                                   
        n3tContact.renderMessage('success', Joomla.JText._('PLG_SYSTEM_N3TCONTACT_JS_SUCCESS'), form);
      if (data.success) 
        form.trigger('reset');
      form.trigger('n3tcontact',true);  
    }).fail(function(){
      n3tContact.renderMessage('error', Joomla.JText._('PLG_SYSTEM_N3TCONTACT_JS_AJAX_ERROR'), form);
      form.trigger('n3tcontact',false);
    }).always(function(){
      systemMessageContainer.attr('id', 'system-message-container');
      container.attr('id', '');

      form.removeClass('n3tContactLoading');
      if (form.data('n3tseznamcaptcha'))
        form.data('n3tseznamcaptcha').reload();                    
    });

    e.preventDefault();
  });    
}

jQuery(function(){
  jQuery('form.n3tContactAjax').each(function(){
    n3tContact.ajaxForm(jQuery(this));    
  });
});